@@ -497,7 +497,7 @@ sub _validate_one_param
     {
 	foreach ( ref $spec->{can} ? @{ $spec->{can} } : $spec->{can} )
 	{
-            unless ( UNIVERSAL::can( $value, $_ ) )
+            unless ( defined $value && $value->can($_) )
             {
                 my $called = _get_called(1);
 
@@ -537,7 +537,7 @@ sub _validate_one_param
 
     if ( exists $spec->{regex} )
     {
-        unless ( $value =~ /$spec->{regex}/ )
+        unless ( defined $value && $value =~ /$spec->{regex}/ )
         {
             my $called = _get_called(1);
 
